Welcome to pactools' documentation!
===================================

This package provides tools to estimate **phase-amplitude coupling (PAC)**
in neural time series.

In particular, it implements the **driven auto-regressive (DAR)**
models presented in [`Dupre la Tour et al. 2017`_].

.. _Dupre la Tour et al. 2017: http://journals.plos.org/ploscompbiol/article?id=10.1371/journal.pcbi.1005893

Contents
--------
.. toctree::
	:maxdepth: 2

	getting_started
	auto_examples/index
	api
	Fork pactools on Github <https://github.com/pactools/pactools>


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
